<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="100px">
      <el-form-item label="信息采集名称" prop="infoName">
        <el-input v-model="queryParams.infoName" placeholder="请输入信息采集名称" clearable
                  @keyup.enter.native="handleQuery"/>
      </el-form-item>
      <el-form-item label="信息采集状态" prop="infoType">
        <el-select v-model="queryParams.infoType" style="width: 100%" placeholder="请选择信息采集状态">
          <el-option
            v-for="dict in dict.type.dict_infotype"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value">
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd">新增
        </el-button>
      </el-col>
      <!--      <el-col :span="1.5">-->
      <!--        <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate">修改-->
      <!--        </el-button>-->
      <!--      </el-col>-->
      <!--      <el-col :span="1.5">-->
      <!--        <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete">删除-->
      <!--        </el-button>-->
      <!--      </el-col>-->
      <!--      <el-col :span="1.5">-->
      <!--        <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport">导出-->
      <!--        </el-button>-->
      <!--      </el-col>-->
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="acquisitionList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <el-table-column type="index" label="序号" width="55" align="center"/>
      <el-table-column label="信息采集名称" min-width="150px" align="center" prop="infoName"/>
      <el-table-column label="信息采集状态" min-width="200px" align="center" prop="infoType">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.dict_infotype" :value="scope.row.infoType"></dict-tag>
        </template>
      </el-table-column>
      <el-table-column label="备注" align="center" min-width="250px" prop="remark"/>
      <el-table-column label="创建时间" min-width="150" align="center" prop="createTime"/>
      <el-table-column label="操作" min-width="250px" align="center"
                       class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <div v-if="scope.row.infoType==0">
            <!--未发布-->
            <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)">修改
            </el-button>
            <el-button size="mini" type="text" icon="el-icon-document" @click="handleData(scope.row)">数据
            </el-button>
            <el-button size="mini" type="text" icon="el-icon-position" @click="handlePut(scope.row)">发布
            </el-button>
            <el-button size="mini" type="text" icon="el-icon-download" @click="handleExport(scope.row)">导出
            </el-button>
            <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)">删除
            </el-button>
          </div>
          <div v-if="scope.row.infoType==1">
            <!--已发布-->
            <el-button size="mini" type="text" icon="el-icon-refresh-left" @click="handleRecall(scope.row)">撤回
            </el-button>
            <el-button size="mini" type="text" icon="el-icon-view" @click="handleDataView(scope.row)">数据查看
            </el-button>
            <el-button size="mini" type="text" icon="el-icon-finished" @click="handleFinish(scope.row)">结束
            </el-button>
          </div>
          <div v-if="scope.row.infoType==2">
            <!--已结束-->
            <el-button size="mini" type="text" icon="el-icon-view" @click="handleDataView(scope.row)">数据查看
            </el-button>
            <el-button size="mini" type="text" icon="el-icon-download" @click="handleExport(scope.row)">导出
            </el-button>
          </div>
        </template>
      </el-table-column>
    </el-table>
    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
                @pagination="getList"/>

    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="110px">
        <el-form-item label="信息采集名称" prop="infoName">
          <el-input v-model="form.infoName" placeholder="请输入信息采集名称"/>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" type="textarea" placeholder="请输入内容"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  listAcquisition,
  getAcquisition,
  delAcquisition,
  addAcquisition,
  updateAcquisition,
  bublicAcquisition,
  endAcquisition,
  revokeAcquisition
} from "@/api/smartSchool/teachAffairAdministration/acquisition/acquisition.js";

export default {
  name: "Acquisition",
  dicts: ['dict_infotype'],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      acquisitionList: [{}],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        infoName: null,
        infoType: null,
        status: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        infoName: [
          {required: true, message: "名称不能为空", trigger: "blur"}
        ]
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询【请填写功能名称】列表 */
    getList() {
      this.loading = false;
      this.loading = true;
      listAcquisition(this.queryParams).then(response => {
        this.acquisitionList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        infoName: null,
        infoType: null,
        remark: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        delFlag: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      // this.resetForm("queryForm");
      this.queryParams = {
        pageNum: 1,
        pageSize: 10,
        infoName: undefined,
        status: null,
      }
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "信息采集新增";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getAcquisition(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "信息采集修改";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateAcquisition(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addAcquisition(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除所选的数据项？').then(function () {
        return delAcquisition(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      });
    },
    /** 导出按钮操作 */
    handleExport(row) {
      this.download('/schoolInfo/export/' + row.id, {
        ...this.queryParams
      }, `信息采集详细数据${Date.parse(new Date())}.xlsx`)
    },
    /** 结束按钮操作 */
    async handleFinish(row) {
      let res = await endAcquisition(row.id)
      if (res.code == 200) {
        this.$modal.msgSuccess("结束成功")
      } else {
        this.$modal.msgError("结束失败")
      }
      this.getList()
    },
    /** 发布按钮操作 */
    async handlePut(row) {
      let res = await bublicAcquisition(row.id)
      if (res.code == 200) {
        this.$modal.msgSuccess("发布成功")
      } else {
        this.$modal.msgError("发布失败")
      }
      this.getList()
    },
    /** 数据按钮操作 */
    handleData(row) {
      this.$router.push({
        path: '/acquisition/dataView',
        query: {
          infoId: row.id,
          infoType: row.infoType,
          title: row.infoName
        }
      })
    },
    /** 数据查看按钮操作 */
    handleDataView(row) {
      this.$router.push({
        path: '/acquisition/dataView',
        query: {
          infoId: row.id,
          infoType: row.infoType,
          title: row.infoName
        }
      })
    },
    /** 撤回按钮操作 */
    async handleRecall(row) {
      let res = await revokeAcquisition(row.id)
      if (res.code == 200) {
        this.$modal.msgSuccess("撤回成功")
      } else {
        this.$modal.msgError("撤回失败")
      }
      this.getList()

    },
  }
};
</script>
